ApiMethod class

A single API method's input contract (params, body, query).

All fields are optional to allow lightweight endpoints and read-only calls.

Constructors

ApiMethod({Map<String, dynamic>? params, Map<String, dynamic>? body, Map<String, dynamic>? query})
ApiMethod.fromJson(Map<String, dynamic> json)
factory

Properties

body Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
params Map<String, dynamic>?
final
query Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited