ContextField class

A name/type pair representing a field or parameter.

Used for response fields, request models, and nested object properties.

Constructors

ContextField({required String name, required String type, bool isList = false, bool isMap = false, bool isCustom = false, required String jsonKey, required bool hasJsonKey})

Properties

hashCode int
The hash code for this object.
no setterinherited
hasJsonKey bool
final
isCustom bool
final
isList bool
final
isMap bool
final
jsonKey String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited