CommandRunner class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkAndAddDeps({required Config config, required String workingDirectory})
→ Future<void>
-
Checks the target project for required dependencies and installs any missing ones.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
runBuildRunner({required String workingDirectory})
→ Future<int>
-
Runs
dart run build_runner build -d in the target project.
-
runFormat({required String featureName, required String workingDirectory})
→ Future<void>
-
Runs
dart format on the generated feature directory.
-
toString()
→ String
-
A string representation of this object.
inherited