Config class

Controls which presentation layer is generated.

Exactly one of bloc or riverpod must be true when provided.

Constructors

Config({bool? bloc, bool? riverpod})
Config.fromJson(Map<String, dynamic> json)
factory

Properties

bloc bool?
final
hashCode int
The hash code for this object.
no setterinherited
riverpod bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited