Context class
Root context passed to the Mustache template engine for code generation.
This is the single source of truth for all template rendering, including nested models, API method contracts, and presentation-layer selection.
Constructors
-
Context({required String name, required String nameLowerCase, required String nameCamelCase, required bool isList, required List<
NestedContextField> fields, required List<ContextMethod> methods, required bool generateUseCase, required String projectRoot, required String projectName, required Config config})
Properties
- config → Config
-
final
-
fields
→ List<
NestedContextField> -
final
- generateUseCase → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isList → bool
-
final
-
methods
→ List<
ContextMethod> -
final
- name → String
-
final
- nameCamelCase → String
-
final
- nameLowerCase → String
-
final
- projectName → String
-
final
- projectRoot → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited