NestedContextField class

Template-ready representation of a nested field.

A root node represents a request/response model, while children represent nested object properties.

Constructors

NestedContextField({required String name, required List<ContextField> properties, bool isRoot = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
isRoot bool
final
name String
final
properties List<ContextField>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited